@@ -34,6 +34,8 @@ namespace bt
 
 namespace kt
 {
+
+	class QueueManager;
 	using bt::TorrentInterface;
 	
 	/**
@@ -43,8 +45,9 @@ namespace kt
 	 * isMember function, but can also provide save and load
 	 * functionality.
 	 */
-	class KTCORE_EXPORT Group
+	class KTCORE_EXPORT Group : public QObject
 	{
+		Q_OBJECT
 	public:
 		enum Properties
 		{
@@ -109,6 +112,12 @@ namespace kt
 		/// Path in the group tree
 		const QString & groupPath() const {return path;}
 		
+		/// Get the number of running torrents
+		int runningTorrents() const {return running;}
+		
+		/// Total torrents
+		int totalTorrents() const {return total;}
+		
 		/// Set the group policy
 		void setGroupPolicy(const Policy & p);
 		
@@ -158,6 +167,12 @@ namespace kt
 		 */
 		virtual void policyChanged();
 		
+		/**
+		 * Update the running and total count
+		 * @param qman The QueueManager
+		 **/
+		void updateCount(QueueManager* qman);
+		
 	protected:
 		QString name;
 		QIcon icon;
@@ -165,6 +180,8 @@ namespace kt
 		int flags;
 		Policy policy;
 		QString path;
+		int running;
+		int total;
 	};
 
 }
