@@ -32,6 +32,7 @@ namespace bt
 namespace kt
 {
 	class View;
+	class Group;
 	
 	/**
 	* Small interface for classes who want to know when
@@ -77,8 +78,8 @@ namespace kt
 		/// Remove a tool widget
 		virtual void removeToolWidget(QWidget* widget) = 0;
 		
-		/// Get the current view
-		virtual View* getCurrentView() = 0;
+		/// Add a new custom group
+		virtual Group* addNewGroup() = 0;
 		
 	protected:
 		/**
