@@ -55,7 +55,7 @@ namespace kt
 	
 		virtual const bt::BitSet & getBitSet() const = 0;
 		virtual void drawContents(QPainter *p);
-		virtual void updateBar();
+		virtual void updateBar(bool force = false);
 	
 	protected:
 		
