@@ -21,15 +21,12 @@
 #ifndef KTCHUNKDOWNLOADMODEL_H
 #define KTCHUNKDOWNLOADMODEL_H
 
+#include <QVector>
 #include <QAbstractTableModel>
 #include <interfaces/chunkdownloadinterface.h>
+#include <interfaces/torrentinterface.h>
 
 
-namespace bt
-{
-	class TorrentInterface;
-}
-
 namespace kt
 {
 
@@ -57,6 +54,9 @@ namespace kt
 		 */
 		void update();
 		
+		/**
+			Clear the model
+		*/
 		void clear();
 
 		virtual int rowCount(const QModelIndex & parent) const;
@@ -67,12 +67,6 @@ namespace kt
 		virtual bool insertRows(int row,int count,const QModelIndex & parent);
 		virtual QModelIndex index(int row,int column,const QModelIndex & parent = QModelIndex()) const;
 		
-	public slots:
-		void sort(int col, Qt::SortOrder order);
-		
-	signals:
-		void sorted();
-		
 	public:
 		struct Item
 		{
@@ -82,15 +76,13 @@ namespace kt
 			
 			Item(bt::ChunkDownloadInterface* cd,const QString & files);
 			
-			bool changed(int col,bool & modified) const;
+			bool changed() const;
 			QVariant data(int col) const;
-			bool lessThan(int col,const Item* other) const;
+			QVariant sortData(int col) const;
 		};
 	private:
-		QList<Item*> items;
-		bt::TorrentInterface* tc;
-		int sort_column;
-		Qt::SortOrder sort_order;
+		QVector<Item*> items;
+		bt::TorrentInterface::WPtr tc;
 	};
 
 }
