@@ -43,8 +43,8 @@ namespace kt
 		virtual int columnCount(const QModelIndex & parent) const;
 		virtual QVariant headerData(int section, Qt::Orientation orientation,int role) const;
 		virtual QVariant data(const QModelIndex & index, int role) const;
-		virtual bool setData(const QModelIndex & index, const QVariant & value, int role); 
 		virtual void update();
+		virtual void changePriority(const QModelIndexList& indexes, bt::Priority newpriority);
 		
 		void filePercentageChanged(bt::TorrentFileInterface* file,float percentage);
 		void filePreviewChanged(bt::TorrentFileInterface* file,bool preview);
@@ -53,6 +53,7 @@ namespace kt
 		void update(const QModelIndex & index,bt::TorrentFileInterface* file,int col);
 		QVariant displayData(Node* n,const QModelIndex & index) const;
 		QVariant sortData(Node* n,const QModelIndex & index) const;
+		void setPriority(Node* n, bt::Priority newpriority, bool selected_node);
 		
 	private:
 		bool preview;
