@@ -22,12 +22,41 @@
 #define KTMEDIAVIEW_H
 
 
-#include <QTreeView>
+#include <QListView>
+#include <QCheckBox>
+#include <QSortFilterProxyModel>
+#include <KSharedConfigPtr>
+#include "mediafile.h"
 
 
+class KLineEdit;
+class KToolBar;
+
 namespace kt
 {
 	class MediaModel;
+	
+	/**
+	 * QSortFilterProxyModel to filter out incomplete files
+	 */
+	class MediaViewFilter : public QSortFilterProxyModel
+	{
+		Q_OBJECT
+	public:
+		MediaViewFilter(QObject* parent = 0);
+		virtual ~MediaViewFilter();
+		
+		virtual bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const;
+		
+		/// Enable or disable showing of incomplete files
+		void setShowIncomplete(bool on);
+		
+	public slots:
+		void refresh();
+		
+	private:
+		bool show_incomplete;
+	};
 
 	/**
 		@author
@@ -39,15 +68,24 @@ namespace kt
 		MediaView(MediaModel* model,QWidget* parent);
 		virtual ~MediaView();
 		
-		/// Get the current selected item
-		QModelIndex selectedItem() const;
+		void saveState(KSharedConfigPtr cfg);
+		void loadState(KSharedConfigPtr cfg);
 		
 	signals:
-		void doubleClicked(const QModelIndex & idx);
+		void doubleClicked(const MediaFileRef & mf);
+		
+	private slots:
+		void onDoubleClicked(const QModelIndex & index);
+		void showIncompleteChanged(bool on);
 
 	private:
 		MediaModel* model;
-		QTreeView* media_tree;
+		QListView* media_tree;
+		KLineEdit* search_box;
+		MediaViewFilter* filter;
+		KToolBar* tool_bar;
+		QAction* show_incomplete;
+		QAction* refresh;
 	};
 
 }
